# 基于角色的系统 - Docker部署指南

## 项目概述
这是一个基于Django的基于角色的系统，使用MySQL数据库和Redis进行WebSocket通信。

## Docker部署步骤

### 前置要求
- 安装 [Docker](https://docs.docker.com/get-docker/)
- 安装 [Docker Compose](https://docs.docker.com/compose/install/)

### 部署步骤

1. **准备环境变量**

   复制示例环境变量文件并根据需要修改：
   ```bash
   cp .env.example .env
   ```

2. **构建并启动容器**

   ```bash
   docker-compose up -d --build
   ```

3. **执行数据库迁移**

   ```bash
   docker-compose exec web python manage.py migrate
   ```

4. **创建超级用户（可选）**

   ```bash
   docker-compose exec web python manage.py createsuperuser
   ```

5. **查看日志（如需调试）**

   ```bash
   docker-compose logs -f
   ```

### 访问应用

应用将在以下地址运行：`http://localhost:8000`

### 停止服务

```bash
docker-compose down
```

### 完全重置（包括数据卷）

```bash
docker-compose down -v
```

## 数据备份与恢复

### 备份数据库

```bash
docker-compose exec db mysqldump -u root -p rolebasedfilemanagement > backup.sql
```

### 恢复数据库

```bash
docker-compose exec -T db mysql -u root -p rolebasedfilemanagement < backup.sql
```

## 注意事项

- 在生产环境中，请确保修改默认密码和密钥
- 生产环境应启用HTTPS
- 定期备份数据库和媒体文件 